#
# spec file for package tripwire
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tripwire
Summary:        A tool to observe the filesystem
License:        GPL-2.0-or-later
Group:          Productivity/Security
Version:        2.4.3.7
Release:        bp155.2.11
Url:            https://github.com/Tripwire/tripwire-open-source
Source:         https://github.com/Tripwire/tripwire-open-source/releases/download/%{version}/tripwire-open-source-%{version}.tar.gz
Source1:        twcfg.txt
Source2:        README.SUSE
Patch0:         tripwire-2.4.1.2-src-policyconfig.patch
Patch1:         tripwire-2.4.3.7-config-dir-location.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  procps
Provides:       Tripwire = %version-%release

%description
By using tripwire, it is possible to observe the filesystem. tripwire
generates a database, controlled by a configuration file, of all
files, their checksums, etc. and it reports changes.

%prep
%setup -q -n tripwire-open-source-%{version}
%patch0 -p1
%patch1 -p1
cp %{S:2} .
autoreconf -f -i

%build
%configure
%make_build CFLAGS="%{optflags}" CPPFLAGS="%{optflags} -std=c++14"

%install
mkdir -p %{buildroot}/etc/tripwire
mkdir -p %{buildroot}/var/lib/tripwire/report
mkdir -p %{buildroot}/%{_mandir}/man4
mkdir -p %{buildroot}/%{_mandir}/man5
mkdir -p %{buildroot}/%{_mandir}/man8
mkdir -p %{buildroot}/usr/sbin
install -m 644 %{S:1} %{buildroot}/etc/tripwire
install -m 700 bin/* %{buildroot}/usr/sbin
for i in `find man -type f -name "*.?"`; do install -m 644 "$i" "%{buildroot}/%{_mandir}/${i#man}"; done

%post
# Transition from old system
if [ -f /etc/tw.cfg ] && [ ! -f /etc/tripwire/tw.cfg ]
then
    mv /etc/tw.cfg /etc/tripwire/tw.cfg
fi

%check
make check

%files
%defattr(-,root,root)
%doc COPYING ChangeLog COMMERCIAL MAINTAINERS TRADEMARK policy/*.txt README.SUSE
%doc %{_mandir}/*/*
%attr(750,root,root) %dir /etc/tripwire
%attr(750,root,root) %dir /var/lib/tripwire
%dir /var/lib/tripwire/report
/usr/sbin/*
%config /etc/tripwire/twcfg.txt

%changelog
* Mon Aug  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 2.4.3.7
- fix build with gcc11
* Fri Jun 28 2019 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Fix bug Bug 1096636 - tripwire looks for the configuration file in
  /etc instead of /etc/tripwire. Now tw.cfg will really appead in /etc/tripwire
  * add patch 'tripwire-2.4.3.7-config-dir-location.patch'
    which update config dir to /etc/tripwire.
  * add build require libtool (which pulls automake and autoconf)
  * add 'autoreconf -a -i' to make sure automake is overwritten
  * Move /etc/tw.cfg to /etc/tripwire/tw.cfg in %%post as make transition smoother
* Sat Mar 23 2019 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update to version 2.4.3.7
- Changes from 2.4.3.2 to 2.4.3.7
  * Run Clang static analyzer & fix some of its quibbles
  * Fix compilation error on Alpine Linux 3.x (Issue #15)
  * Fix file permissions on a couple of source files (Issue #14)
  * Fix some errors w/ make install/uninstall/dist (Issue #15)
  * Fix a new issue with level 2 report printing ( Issue #19 )
  * Fix 'make install-strip' target, which wasn't actually
    stripping binaries (Issue #20)
  * Updated release to include archives with curl/wget-friendly names (Issue #22)
  * Buildsys: 'install-strip', 'uninstall', 'check', and 'distcheck'
    make targets now do useful things. (the install-strip change
    addresses the remaining bit of issue #18.)
  * Buildsys: To support old flavors of gcc, add "--disable-extrawarnings"
    configure option for compilers that don't understand -Wextra arg, and
    detect if the local g++ happens to be called c++.
  * Fix various new warnings w/ GCC 7.
  * Use std::unique_ptr instead of deprecated std::auto_ptr, where available.
  * Clean up / enable more twtest unit tests, & tweak the framework for clarity.
  * Remove more dead code and strip out a bunch of uses of the always-true IS_UNIX ifdef.
  * Address some static analysis warnings from CppCheck & Flawfinder
  * Add a sanity check in fcodatasourceiterimpl to address a unit test that failed on some platforms.
  * Update old policy test files in src/parser/testfiles to use current policy syntax.
  * Fix & expand tests in Perl acceptance test framework
  * Fix & expand twtest unit tests, & rework unit test mini-framework so they’re
    referenced by name, not some numeric ID, and list tests as “skipped" if
    they don’t make any test assertions.
  * Add configure options to enable coverage, profiling, & use
    /dev/urandom as RNG (all off by default)
  * Add a ‘list’ make target to list all make targets
  * Remove dead code & add test coverage per gcov+lcov results
  * Fix various memory issues pointed out by valgrind
  * In examine-encryption mode, better reporting (& nonzero exit) if we can't find a
    keyfile for the examined file.
  * More exception handling around individual objects & init/IC as a whole,
    since there have been occasional reports of uncaught exceptions during init or check,
    and so far haven’t been able to repro or figure out what circumstances
    it occurs under. (e.g. Github issue #25)
  * Tweak install.sh so it can be run directly, not just thru 'make install'
    if you want. (Github issue #26)
  * Improve native (non-Posixy) path handling on platforms that need it (DOS, AROS, RISC OS, Redox)
  * New platforms: MirOS BSD, Bitrig, LibertyBSD, RISC OS, Redox
  * Add default policies for HP-UX & various BSDs
  * Fix & expand tests in Perl acceptance test framework
  * Fix & expand twtest unit tests, & rework unit test mini-framework so they’re
    referenced by name, not some numeric ID, and list tests as “skipped" if they
    don’t make any test assertions.
  * Add configure options to enable coverage, profiling, & use /dev/urandom as RNG (all off by default)
  * Add a ‘list’ make target to list all make targets
  * Remove dead code & add test coverage per gcov+lcov results
  * Fix various memory issues pointed out by valgrind
  * In examine-encryption mode, better reporting (& nonzero exit) if we can't find
    a keyfile for the examined file.
  * More exception handling around individual objects & init/IC as a whole,
    since there have been occasional reports of uncaught exceptions during
    init or check, and so far haven’t been able to repro or figure out what
    circumstances it occurs under. (e.g. Github issue #25)
  * Tweak install.sh so it can be run directly, not just thru
    'make install' if you want. (Github issue #26)
  * Improve native (non-Posixy) path handling on platforms that
    need it (DOS, AROS, RISC OS, Redox)
  * New platforms: MirOS BSD, Bitrig, LibertyBSD, RISC OS, Redox
  * Add default policies for HP-UX & various BSDs
  * twprint can now print reports for individual objects.
  * twprint now has verbosity levels for --print-dbfile mode.
  * Provide a useful README.md (issue #17 ).
  * Document return codes in man pages (issue #28 ).
  * Update install script after testing on additional platforms.
  * Provide default policies for more operating systems, and update some
    existing policies
  * Usability tweaks to twtest.
  * Clean up code style with clang-format, & add a custom style that
    approximates existing OST usage.
  * Update copyright dates to 2018.
* Thu Mar 23 2017 jengelh@inai.de
- Replace old $RPM_* shell variables by macros.
- Provide "Tripwire" with full version
- Trim manual from description.
* Fri Mar  3 2017 meissner@suse.com
- removed author credits from description.
* Thu Feb  9 2017 meissner@suse.com
- Updated to 2.4.3.2 (bsc#1024442)
  See:
  https://github.com/Tripwire/tripwire-open-source/releases
- tripwire-2.4.1.2-src-off_t.patch: fixed upstream
- tripwire-2.4.1.2-src-undefined-operation.patch: fixed upstream
- README.SuSE -> README.SUSE
* Thu Aug 30 2012 Greg.Freemyer@gmail.com
- added gcc47 patch to allow build to work
- upgrade to 2.4.2.2
  * Bumping version to 2.4.2.2
  * Updated version revision in reports and all
  * Added experimental policy creation (see policy/policy_generator_readme.txt)
  * Fixed report formating and sendmail issues
  * Added Debian patches for crypto and hostnames
  * Fixed compiling issue on recent GCC compilers (-fpermissive)
  * Added patch to fix bug [ 1962485 ] Cannot change or expect-script
* Thu Jun  4 2009 poeml@suse.de
- support large files (>2GB), by defining the correct type for file
  sizes.
    tripwire-2.4.1.2-src-off_t.patch
- fix build failure due to compile warning about undefined
  behaviour when incrementing variables
    tripwire-2.4.1.2-src-undefined-operation.patch
- make sure that RPM_OPT_FLAGS are used when compiling.
* Thu Jun  4 2009 poeml@suse.de
- fix paths in the sample twpol-Linux.txt
- remove obsolete patches
- update README.SuSE a bit
- package config directory and database directory to be readable
  only for root
* Thu Jun  4 2009 poeml@suse.de
- take SLES9 package and update it to 2.4.1.2
* Fri Jun 18 2004 tcrhak@suse.cz
- format string fix (patch format, bug #41622)
* Wed Mar 31 2004 tcrhak@suse.cz
- fixed for big endian archs (patch endian)
* Mon Mar 29 2004 tcrhak@suse.cz
- fixed for x86_64 (bug #36050, patch types)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Jan 27 2003 ro@suse.de
- use stdarg
* Mon Jan  6 2003 tcrhak@suse.cz
- update to version 2.3.1
- created README.SuSE and twcfg.txt
* Wed Nov 13 2002 ro@suse.de
- fix for current bison (end all rules with ";")
* Mon Mar 25 2002 stepan@suse.de
- fix 64bit overflow bug
* Fri Mar 15 2002 tcrhak@suse.cz
- added dir /usr/share/lib/tripwire to filelist
* Mon Aug 13 2001 adostal@suse.cz
- apply tripwire-1.2.patch and makefile.patch
- fixed spec file (patches, RPM_BUILD_ROOT)
* Tue Jul 31 2001 adostal@suse.cz
- convert source to bz2 and dif to patch
* Wed Mar  1 2000 choeger@suse.de
- added mandir
* Thu Oct 28 1999 ro@suse.de
- fixed to build on alpha
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Sep 14 1998 choeger@suse.de
- just another fix for german 'umlaute'
* Tue Sep  1 1998 choeger@suse.de
- added siggen to the list of files...
* Thu Jul  2 1998 choeger@suse.de
- changed some path's
* Mon Jun 29 1998 choeger@suse.de
- new package, v1.2
